==> jc-1.4.0.tar.gz: soot/baf/toolkits/base/ExamplePeephole.h <==
// public class soot.baf.toolkits.base.ExamplePeephole

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class deba9086a8880c47 soot_baf_toolkits_base_ExamplePeephole

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_baf_toolkits_base_ExamplePeephole_H_
#define _JC_soot_baf_toolkits_base_ExamplePeephole_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs	_jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs	_jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$refs	_jc_soot_baf_toolkits_base_ExamplePeephole$refs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs	_jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$object	_jc_soot_baf_toolkits_base_ExamplePeephole$object;

typedef const struct _jc_soot_baf_toolkits_base_ExamplePeephole$vmethods	_jc_soot_baf_toolkits_base_ExamplePeephole$vmethods;
typedef const struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtable	_jc_soot_baf_toolkits_base_ExamplePeephole$vtable;
typedef const struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtype	_jc_soot_baf_toolkits_base_ExamplePeephole$vtype;

// Constructors
extern void _jc_soot_baf_toolkits_base_ExamplePeephole$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *);

// Virtual methods
extern jboolean _jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443(_jc_env *, struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *, struct _jc_soot_Body$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443;

// Virtual methods structure
struct _jc_soot_baf_toolkits_base_ExamplePeephole$vmethods {
	jboolean	(*apply$26c2d07493ac3443)(_jc_env *, struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *, struct _jc_soot_Body$object *);
};

// Vtable
struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_baf_toolkits_base_ExamplePeephole$vmethods	soot_baf_toolkits_base_ExamplePeephole;
};

// Vtype
struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtype {
	_jc_type			type;
	_jc_soot_baf_toolkits_base_ExamplePeephole$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$refs {
    _jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs	soot_baf_toolkits_base_ExamplePeephole;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs	soot_baf_toolkits_base_ExamplePeephole;
};

// Object instance structure
struct _jc_soot_baf_toolkits_base_ExamplePeephole$object {
	_jc_soot_baf_toolkits_base_ExamplePeephole$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_toolkits_base_ExamplePeephole$vtype	*vtype;
	_jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_toolkits_base_ExamplePeephole$vtype _jc_soot_baf_toolkits_base_ExamplePeephole$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_toolkits_base_ExamplePeephole, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_toolkits_base_ExamplePeephole$class_object;

#endif	/* _JC_soot_baf_toolkits_base_ExamplePeephole_H_ */

==> jc-1.4.6.tar.gz: soot/baf/toolkits/base/ExamplePeephole.h <==
// public class soot.baf.toolkits.base.ExamplePeephole

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class deba9086a8880c47 soot_baf_toolkits_base_ExamplePeephole

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_baf_toolkits_base_ExamplePeephole_H_
#define _JC_soot_baf_toolkits_base_ExamplePeephole_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs	_jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs	_jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$refs	_jc_soot_baf_toolkits_base_ExamplePeephole$refs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs	_jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs;
typedef struct _jc_soot_baf_toolkits_base_ExamplePeephole$object	_jc_soot_baf_toolkits_base_ExamplePeephole$object;

typedef const struct _jc_soot_baf_toolkits_base_ExamplePeephole$vmethods	_jc_soot_baf_toolkits_base_ExamplePeephole$vmethods;
typedef const struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtable	_jc_soot_baf_toolkits_base_ExamplePeephole$vtable;
typedef const struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtype	_jc_soot_baf_toolkits_base_ExamplePeephole$vtype;

// Constructors
extern void _jc_soot_baf_toolkits_base_ExamplePeephole$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_baf_toolkits_base_ExamplePeephole$method$apply$26c2d07493ac3443(_jc_env *, struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_toolkits_base_ExamplePeephole$method_info$apply$26c2d07493ac3443;

// Virtual methods structure
struct _jc_soot_baf_toolkits_base_ExamplePeephole$vmethods {
	jboolean	(*apply$26c2d07493ac3443)(_jc_env *, struct _jc_soot_baf_toolkits_base_ExamplePeephole$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_baf_toolkits_base_ExamplePeephole$vmethods	soot_baf_toolkits_base_ExamplePeephole;
};

// Vtype
struct _jc_soot_baf_toolkits_base_ExamplePeephole$vtype {
	_jc_type			type;
	_jc_soot_baf_toolkits_base_ExamplePeephole$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$refs {
    _jc_soot_baf_toolkits_base_ExamplePeephole$sub_refs	soot_baf_toolkits_base_ExamplePeephole;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_baf_toolkits_base_ExamplePeephole$sub_nonrefs	soot_baf_toolkits_base_ExamplePeephole;
};

// Object instance structure
struct _jc_soot_baf_toolkits_base_ExamplePeephole$object {
	_jc_soot_baf_toolkits_base_ExamplePeephole$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_toolkits_base_ExamplePeephole$vtype	*vtype;
	_jc_soot_baf_toolkits_base_ExamplePeephole$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_toolkits_base_ExamplePeephole$vtype _jc_soot_baf_toolkits_base_ExamplePeephole$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_toolkits_base_ExamplePeephole, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_toolkits_base_ExamplePeephole$class_object;

#endif	/* _JC_soot_baf_toolkits_base_ExamplePeephole_H_ */
